const apiUrl = "./api.php";

// Add new leaderboard entry
document.getElementById("add-entry-form").addEventListener("submit", async (e) => {
    e.preventDefault();
    const name = document.getElementById("entry-name").value.trim();
    const points = parseInt(document.getElementById("entry-points").value.trim(), 10);

    if (!name || isNaN(points)) {
        document.getElementById("add-entry-result").textContent = "Invalid name or points.";
        return;
    }

    try {
        const response = await fetch(apiUrl, {
            method: "POST",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify({ name, points }),
        });
        if (response.ok) {
            document.getElementById("add-entry-result").textContent = "Entry added successfully!";
            fetchLeaderboardEntries(); // Refresh entries
        } else {
            document.getElementById("add-entry-result").textContent = "Failed to add entry.";
        }
    } catch (error) {
        console.error("Error adding entry:", error);
        document.getElementById("add-entry-result").textContent = "Error connecting to the server.";
    }
});

// Apply theme settings
document.getElementById("apply-theme-settings").addEventListener("click", async () => {
    const bgColor = document.getElementById("bg-color-picker").value;
    const textColor = document.getElementById("text-color-picker").value;

    try {
        await fetch(apiUrl, {
            method: "PUT",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify({ bg_color: bgColor, text_color: textColor }),
        });
        alert("Theme updated successfully!");
    } catch (error) {
        console.error("Error updating theme settings:", error);
    }
});

// Fetch current settings
async function fetchSettings() {
    try {
        const response = await fetch(`${apiUrl}?settings=true`);
        const data = await response.json();

        // Populate settings in the admin page
        document.getElementById("transition-time-slider").value = data.settings.transition_time;
        document.getElementById("transition-time-value").textContent = `${data.settings.transition_time} ms`;
        document.getElementById("bg-color-picker").value = data.settings.bg_color;
        document.getElementById("text-color-picker").value = data.settings.text_color;
    } catch (error) {
        console.error("Error fetching settings:", error);
    }
}

// Update transition time
document.getElementById("apply-transition-time").addEventListener("click", async () => {
    const transitionTime = document.getElementById("transition-time-slider").value;

    try {
        await fetch(apiUrl, {
            method: "PUT",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify({ transition_time: transitionTime }),
        });
        alert("Transition time updated!");
    } catch (error) {
        console.error("Error updating transition time:", error);
    }
});

// Reset leaderboard
document.getElementById("reset-leaderboard").addEventListener("click", async () => {
    try {
        await fetch(apiUrl, { method: "DELETE" });
        alert("Leaderboard reset successfully!");
        fetchLeaderboardEntries(); // Refresh entries
    } catch (error) {
        console.error("Error resetting leaderboard:", error);
    }
});

// Fetch leaderboard entries
async function fetchLeaderboardEntries() {
    try {
        const response = await fetch(apiUrl);
        const data = await response.json();
        const container = document.getElementById("leaderboard-entries");
        container.innerHTML = data.entries
            .map(
                (entry, index) => `
                    <div class="leaderboard-entry">
                        <span>${index + 1}</span>
                        <span>${entry.name}</span>
                        <span>${entry.points} PTS</span>
                    </div>`
            )
            .join("");
    } catch (error) {
        console.error("Error fetching leaderboard entries:", error);
    }
}

// Update transition time slider display value
document.getElementById("transition-time-slider").addEventListener("input", (event) => {
    document.getElementById("transition-time-value").textContent = `${event.target.value} ms`;
});

// Initialize admin page
fetchSettings();
fetchLeaderboardEntries();
