<?php
header("Content-Type: application/json");

$database_file = 'leaderboard.sqlite';

try {
    // Connect to SQLite database
    $db = new PDO("sqlite:$database_file");
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Create tables if they don't exist
    $db->exec("CREATE TABLE IF NOT EXISTS leaderboard (
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        name TEXT NOT NULL,
        points INTEGER NOT NULL
    )");

    $db->exec("CREATE TABLE IF NOT EXISTS settings (
        id INTEGER PRIMARY KEY,
        transition_time INTEGER DEFAULT 5000,
        bg_color TEXT DEFAULT '#222222',
        text_color TEXT DEFAULT '#ffffff'
    )");

    $db->exec("INSERT OR IGNORE INTO settings (id, transition_time, bg_color, text_color) VALUES (1, 5000, '#222222', '#ffffff')");

    // Handle API requests
    $method = $_SERVER['REQUEST_METHOD'];

    if ($method === 'GET' && !isset($_GET['settings'])) {
        // Fetch leaderboard data
        $query = $db->query("SELECT name, points FROM leaderboard ORDER BY points DESC");
        $entries = $query->fetchAll(PDO::FETCH_ASSOC);
        echo json_encode(["entries" => $entries]);

    } elseif ($method === 'GET' && isset($_GET['settings'])) {
        // Fetch settings
        $query = $db->query("SELECT * FROM settings WHERE id = 1");
        $settings = $query->fetch(PDO::FETCH_ASSOC);
        echo json_encode(["settings" => $settings]);

    } elseif ($method === 'POST') {
        // Add a new leaderboard entry
        $data = json_decode(file_get_contents("php://input"), true);

        if (!empty($data['name']) && isset($data['points'])) {
            $stmt = $db->prepare("INSERT INTO leaderboard (name, points) VALUES (:name, :points)");
            $stmt->bindParam(':name', $data['name']);
            $stmt->bindParam(':points', $data['points'], PDO::PARAM_INT);
            $stmt->execute();
            echo json_encode(["message" => "Entry added successfully!"]);
        } else {
            echo json_encode(["error" => "Invalid data provided."]);
        }

    } elseif ($method === 'PUT') {
        // Update settings
        $data = json_decode(file_get_contents("php://input"), true);

        if (isset($data['transition_time'], $data['bg_color'], $data['text_color'])) {
            $stmt = $db->prepare("UPDATE settings SET transition_time = :transition_time, bg_color = :bg_color, text_color = :text_color WHERE id = 1");
            $stmt->bindParam(':transition_time', $data['transition_time'], PDO::PARAM_INT);
            $stmt->bindParam(':bg_color', $data['bg_color']);
            $stmt->bindParam(':text_color', $data['text_color']);
            $stmt->execute();
            echo json_encode(["message" => "Settings updated successfully!"]);
        } else {
            echo json_encode(["error" => "Invalid settings data."]);
        }

    } elseif ($method === 'DELETE') {
        // Reset the leaderboard
        $db->exec("DELETE FROM leaderboard");
        echo json_encode(["message" => "Leaderboard reset successfully!"]);
    } else {
        echo json_encode(["error" => "Invalid request method."]);
    }
} catch (PDOException $e) {
    echo json_encode(["error" => $e->getMessage()]);
}
