const apiUrl = "./api.php";

let currentPage = 0;
let totalPages = 0;
let leaderboardData = [];
let transitionTime = 5000;

// Fetch leaderboard data
async function fetchLeaderboardData() {
    try {
        const response = await fetch(apiUrl);
        if (!response.ok) throw new Error(`HTTP error! status: ${response.status}`);
        const data = await response.json();
        leaderboardData = data.entries || []; // Fallback to an empty array if `entries` is undefined
        totalPages = Math.ceil(leaderboardData.length / 12);
    } catch (error) {
        console.error("Error fetching leaderboard data:", error);
    }
}

// Render leaderboard page
function renderPage() {
    const container = document.getElementById("tv-leaderboard");
    if (!container) {
        console.error("Leaderboard container not found!");
        return;
    }

    if (leaderboardData.length === 0) {
        container.innerHTML = "<p>No leaderboard data available.</p>";
        return;
    }

    const startIndex = currentPage * 12;
    const endIndex = startIndex + 12;
    const currentData = leaderboardData.slice(startIndex, endIndex);

    container.innerHTML = currentData
        .map(
            (entry, index) => `
                <div class="leaderboard-entry">
                    <span>${startIndex + index + 1}</span>
                    <span>${entry.name || "Unknown"}</span>
                    <span>${entry.points || 0} PTS</span>
                </div>`
        )
        .join("");

    currentPage = (currentPage + 1) % totalPages;
}

// Fetch and apply theme settings
async function fetchThemeSettings() {
    try {
        const response = await fetch(`${apiUrl}?settings=true`);
        if (!response.ok) throw new Error(`HTTP error! status: ${response.status}`);
        const data = await response.json();
        const settings = data.settings || {};

        // Apply theme settings
        document.documentElement.style.setProperty("--leaderboard-bg-color", settings.bg_color || "#222");
        document.documentElement.style.setProperty("--leaderboard-text-color", settings.text_color || "#fff");

        // Update transition time
        transitionTime = settings.transition_time || 5000;
    } catch (error) {
        console.error("Error fetching theme settings:", error);
    }
}

// Auto-check for updates every 2 seconds
async function autoUpdate() {
    await fetchLeaderboardData();
    renderPage();
}

// Initialize leaderboard
async function initializeLeaderboard() {
    await fetchThemeSettings(); // Apply theme settings
    await fetchLeaderboardData(); // Fetch leaderboard data
    renderPage(); // Render the first page

    // Set up automatic updates
    setInterval(autoUpdate, 2000);
}

// Start the leaderboard
initializeLeaderboard();
